# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2020-03-26 21:32
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_project', '0007_customer_owner'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='customer',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'control')},
        ),
        migrations.AlterModelOptions(
            name='member',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'control')},
        ),
        migrations.AlterModelOptions(
            name='project',
            options={'default_permissions': ('add', 'change', 'delete', 'view', 'control')},
        ),
    ]
